function myBode(num,den)
% Draw the bode diagram by using the Matlab built-in function. It solves
% the drawing issues with non-minimum phase poles/zeros and negative static
% gains
%
% %% Example of Usage
% % Parameters
% num = [1 2];
% den = [1 11 28];
%
% 
% bode_asymptotic(num,den);
%
% % Alternative Usage
% s = tf('s');
% P = (s+2)/(s^2 + 11*s + 28)
%
% bode_asymptotic(P);
%


if nargin<2
    den=num.den{1};
    num=num.num{1};
end


% Define Transfer Functions
s=tf('s');
G=tf(num,den);

% Detect Poles-Zeros Excess 
zroots=roots(num);
proots=roots(den);
% Find number of zeros at origin
[iz,~]=find(abs(zroots)==0);
numz=length(iz);
% Find number of poles at origin
[ip,~]=find(abs(proots)==0);
nump=length(ip);
% Poles-Zeros Excess 
h=nump-numz;


% Phase Offset Computation
% The idea is to remove the contribution of a negative gain and off all
% the pole at the origin and bring it back later. In this way, we can
% compute exactly the value of the frequency responce for the residual
% system at low frequency and then add back the phase contribution due 
% to the negative gain and the poles at the origin
if (dcgain(s^h*G)<0)
    % Pretend Gain to be positive
    po=rad2deg(angle(freqresp(s^h*-G,1)));
    % Add contribution of negative gain
    po = po - 180;
    % Add contribution of pole at origin
    po = po - 90*h;
else
    % Gain is positive
    po=rad2deg(angle(freqresp(s^h*G,1)));
    po = po - 90*h;
end

% Bode Plot with Phase Correction
h=bodeplot(G);
p = getoptions(h);
p.PhaseMatching = 'on';
p.PhaseMatchingFreq = 1;
p.PhaseMatchingValue = po;
setoptions(h,p);